| host_domain | R Documentation |
This function assigns to the host, or genome, the respective domain, archeae, bacteria or eukarya #'
host_domain(vcontact_df, reduce_names = FALSE)
vcontact_df |
dataframe from vcontact2 |
reduce_names |
if TRUE separates the Genome column so that only the host genus is present, default set to FALSE |
## Not run:
quiet(cat("test"))
quiet(warning("test"))
quiet(warning("test"), all=T)
## End(Not run)
# This is a function that suppresses log info
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.